@@ -10,6 +10,8 @@ import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_lambda_nodejs._jsii
+import aws_cdk.aws_lambda_python._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_logs_destinations._jsii
 import aws_cdk.core._jsii
@@ -17,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "datadog-cdk-constructs",
-    "0.3.0",
+    "0.6.0",
     __name__[0:-6],
-    "datadog-cdk-constructs@0.3.0.jsii.tgz",
+    "datadog-cdk-constructs@0.6.0.jsii.tgz",
 )
 
 __all__ = [
